// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array or 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js

angular.module(
    'TrumanApp',
    [
        'ionic', 'ngRoute', 'ngAnimate',
        'TrumanApp.home',
        'TrumanApp.filters',
        'TrumanApp.calendar',
        'TrumanApp.search',
        'TrumanApp.grades',
        'TrumanApp.services',
        'TrumanApp.schedule',
        'TrumanApp.map',
        'TrumanApp.academics',
        'TrumanApp.news',
        'TrumanApp.youtube',
        'TrumanApp.tmn',
        'TrumanApp.lab',
        'TrumanApp.library',
        'TrumanApp.liveStream',
        'TrumanApp.departmentFeeds',
        'ngCordova'
    ]
    )

    .constant(
        'CONFIG',
        {
            CACHE_ENABLED: false,
            TERMS_API_URL: 'https://api.truman.edu/truman/terms?sort=desc&last=10&interim=false&finaid=false',
            BANNER_GRADES_API_URL: 'https://api.truman.edu/banner/grades',
            BANNER_SCHEDULE_API_URL: 'https://api.truman.edu/banner/schedule',
            TRUMAN_TODAY_FEED_API_URL: 'http://api.truman.edu/its/truman-today-feed',
            TRUMAN_TODAY_API_URL: 'http://api.truman.edu/trumantoday',
            CAMPUS_EVENTS_API_URL: 'http://api.truman.edu/truman/events/on-campus',
            FEED_LIST_API_URL: 'https://api.truman.edu/feeds-list',
            DEPT_FEED_API_URL: 'https://api.truman.edu/feeds',
            LAB_AVAIL_API_URL: 'http://api.truman.edu/its/lab-availability',
            KTRM_NOW_PLAYING_URL: 'http://tmn.truman.edu/simian/nowplaying.txt'
        }
    )

    .config(
        function ($compileProvider) {
            // Needed for routing to work
            $compileProvider.aHrefSanitizationWhitelist(/^\s*(https?|ftp|mailto|file):/);
        }
    )

    .config(
        function ($routeProvider) {

            // Set up the initial routes that our app will respond to.
            // These are then tied up to our nav router which animates and
            // updates a navigation bar
            $routeProvider.when(
                '/calendar',
                {
                    templateUrl: 'js/app/calendar/calendar.html',
                    controller: 'CalendarCtrl',
                    data: {
                        title: 'Calendar'
                    }
                }
            );

            $routeProvider.when(
                '/search',
                {
                    templateUrl: 'js/app/search/search.html',
                    controller: 'SearchCtrl',
                    data: {
                        title: 'Directory Search'
                    }
                }
            );

            $routeProvider.when(
                '/news',
                {
                    templateUrl: 'js/app/news/news.html',
                    controller: 'NewsCtrl',
                    data: {
                        title: 'News'
                    }
                }
            );

            $routeProvider.when(
                '/map',
                {
                    templateUrl: 'js/app/map/map.html',
                    controller: 'MapCtrl',
                    data: {
                        title: 'Map'
                    }
                }
            );

            $routeProvider.when(
                '/academics',
                {
                    templateUrl: 'js/app/academics/academics.html',
                    controller: 'AcademicsCtrl',
                    data: {
                        title: 'Academics'
                    }
                }
            );

            $routeProvider.when(
                '/schedule',
                {
                    templateUrl: 'js/app/schedule/schedule.html',
                    controller: 'ScheduleCtrl',
                    data: {
                        title: 'Class Schedule'
                    }
                }
            );

            $routeProvider.when(
                '/grades',
                {
                    templateUrl: 'js/app/grades/grades.html',
                    controller: 'GradesCtrl',
                    data: {
                        title: 'Grades'
                    }
                }
            );

            $routeProvider.when(
                '/lab',
                {
                    templateUrl: 'js/app/lab/lab.html',
                    controller: 'LabCtrl',
                    data: {
                        title: 'Lab Availability'
                    }
                }
            );

            $routeProvider.when(
                '/library',
                {
                    templateUrl: 'js/app/library/library.html',
                    controller: 'LibraryCtrl',
                    data: {
                        title: 'Library'
                    }
                }
            );

            $routeProvider.when(
                '/youtube',
                {
                    templateUrl: 'js/app/youtube/youtube.html',
                    controller: 'YoutubeCtrl',
                    data: {
                        title: 'Truman Youtube'
                    }
                }
            );

            $routeProvider.when(
                '/tmn',
                {
                    templateUrl: 'js/app/tmn/tmn.html',
                    controller: 'TmnCtrl',
                    data: {
                        title: 'TMN'
                    }
                }
            );

            $routeProvider.when(
                '/liveStream',
                {
                    templateUrl: 'js/app/liveStream/liveStream.html',
                    controller: 'LiveStreamCtrl',
                    data: {
                        title: 'KTRM'
                    }
                }
            );

            $routeProvider.when(
                '/departmentFeeds',
                {
                    templateUrl: 'js/app/departmentFeeds/departmentFeeds.html',
                    controller: 'DepartmentFeedsCtrl',
                    data: {
                        title: 'Department Feeds'
                    }
                }
            );

            $routeProvider.when(
                '/home',
                {
                    templateUrl: 'js/app/home/home.html',
                    controller: 'HomeCtrl',
                    data: {
                        title: 'Home'
                    }
                }
            );

            // if none of the above routes are met, use this fallback
            // which executes the 'AppCtrl' controller (controllers.js)
            $routeProvider.otherwise(
                {
                    redirectTo: '/home'
                }
            );
        }
    )

    .directive(
        "trumanTutorial",
        function () {
            return {
                restrict: "A",
                link: function (scope, element) {

                    if (!localStorage) {

                        alert("Doesn't support local storage");
                        element.parent().addClass("hide");
                    }

                    if (localStorage.getItem("been-here-before")) {

                        element.parent().addClass("hide");
                    }

                    element.bind(
                        "click",
                        function () {

                            $(this).addClass("hide");

                            if ($(this).hasClass("end-image")) {

                                element.parent().addClass("hide");
                                localStorage.setItem("been-here-before", true);

                            } else {

                                $(this).next().attr("src", changeSrc($(this).next().attr("src")));
                                $(this).next().removeClass("hide");
                            }
                        }
                    );

                    window.addEventListener(
                        "orientationchange",
                        function () {

                            if (!element.hasClass("hide")) {

                                element.attr("src", changeSrc(element.attr("src")));
                            }
                        }
                    );

                    function changeSrc(oldSrc) {

                        var innerHeight = window.innerHeight;
                        var innerWidth = window.innerWidth;
                        var afterSplit = oldSrc.split("-");
                        var lengthOfSplit = afterSplit.length;

                        if (innerHeight > innerWidth) {

                            afterSplit[lengthOfSplit - 1] = "portrait.png";

                        } else {

                            afterSplit[lengthOfSplit - 1] = "landscape.png";
                        }

                        return afterSplit.join("-");
                    }
                }
            }
        }
    )

    .directive(
        "youtubeTutorial",
        function () {

            return {
                restrict: "A",
                link: function (scope, element) {

                    if (!localStorage) {

                        alert("Doesn't support local storage");
                        element.parent().addClass("hide");
                    }

                    if (localStorage.getItem("youtube-tutorial")) {

                        element.parent().addClass("hide");
                    }

                    element.bind(
                        "click",
                        function () {

                            $(this).addClass("hide");

                            if ($(this).hasClass("end-image")) {

                                element.parent().addClass("hide");
                                localStorage.setItem("youtube-tutorial", true);

                            } else {

                                $(this).next().attr("src", changeSrc($(this).next().attr("src")));
                                $(this).next().removeClass("hide");
                            }
                        }
                    );

                    window.addEventListener(
                        "orientationchange",
                        function () {

                            if (!element.hasClass("hide")) {
                                element.attr("src", changeSrc(element.attr("src")));
                            }
                        }
                    );

                    function changeSrc(oldSrc) {

                        var innerHeight = window.innerHeight;
                        var innerWidth = window.innerWidth;
                        var afterSplit = oldSrc.split("-");
                        var lengthOfSplit = afterSplit.length;

                        if (innerHeight > innerWidth) {

                            afterSplit[lengthOfSplit - 1] = "portrait.png";

                        } else {

                            afterSplit[lengthOfSplit - 1] = "landscape.png";
                        }

                        return afterSplit.join("-");
                    }
                }
            }
        }
    )

    .controller(
        "TutorialCtrl",
        [
            function () {

                // TODO You'll want to remove this for production mode :)
                var _dev = false;

                if (_dev) {

                    localStorage.removeItem("been-here-before");
                    localStorage.removeItem("youtube-tutorial");
                }
            }
        ]
    )

    /**
     * Primary controller for the index page
     *
     * @deps $scope, $ionicSideMenuDelegate
     */
    .controller(
        'AppCtrl',
        [
            '$scope',
            '$ionicSideMenuDelegate',
            '$window',
            function ($scope, $ionicSideMenuDelegate, $window) {

                $scope.windowWidth = $window.innerWidth;
                $scope.leftNavVisible = false;
                $scope.rightNavVisible = false;
                $scope.mainContentVisible = true;


                document.addEventListener(
                    "deviceready",
                    function () {

                        document.addEventListener("backbutton", onBackKeyDown, false);
                    },
                    false
                );

                $scope.$on(
                    '$routeChangeStart',
                    function (event, next) {

                        if (next.data) {
                            $scope.pageTitle = next.data.title;
                        }
                    }
                );

                function onBackKeyDown(e) {
                    //e.preventDefault();
                    //e.stopPropagation();
                }

                angular.element($window).bind(
                    'resize',
                    function () {

                        $scope.windowWidth = $window.innerWidth;
                        $scope.$apply();
                    }
                );

                $scope.redirect = function () {
                    window.open('http://library.truman.edu/', '_blank', 'location=yes');
                };

                $scope.openRight = function () {

                    if (!$ionicSideMenuDelegate.isOpenRight()) {

                        $scope.leftNavVisible = false;
                        $scope.rightNavVisible = true;
                        $scope.mainContentVisible = false;

                    } else {

                        $scope.leftNavVisible = false;
                        $scope.rightNavVisible = false;
                        $scope.mainContentVisible = true;
                    }

                    $ionicSideMenuDelegate.toggleRight();
                };

                $scope.openLeft = function () {

                    if (!$ionicSideMenuDelegate.isOpenLeft()) {

                        $scope.leftNavVisible = true;
                        $scope.rightNavVisible = false;
                        $scope.mainContentVisible = false;

                    } else {

                        $scope.leftNavVisible = false;
                        $scope.rightNavVisible = false;
                        $scope.mainContentVisible = true;
                    }

                    $ionicSideMenuDelegate.toggleLeft();
                };

                $scope.closeNavigation = function () {

                    if ($ionicSideMenuDelegate.isOpenLeft()) {

                        $ionicSideMenuDelegate.toggleLeft();
                    }

                    if ($ionicSideMenuDelegate.isOpenRight()) {

                        $ionicSideMenuDelegate.toggleRight();
                    }

                    $scope.leftNavVisible = false;
                    $scope.rightNavVisible = false;
                    $scope.mainContentVisible = true;
                };

                // changes the class of the icon based on the ratio of the menu
                //  uses the fact that when a side menu is fully opened, the ratio is 1
                //  for left menu, and -1 for right menu
                $scope.$watch(
                    $ionicSideMenuDelegate.getOpenRatio,
                    function (value) {

                        if (value == 1) {

                            $scope.leftNavVisible = true;
                            $scope.rightNavVisible = false;
                            $scope.mainContentVisible = false;
                        }

                        if (value == -1) {

                            $scope.leftNavVisible = false;
                            $scope.rightNavVisible = true;
                            $scope.mainContentVisible = false;
                        }
                    }
                );
            }
        ]
    );

(function (window, document) {

    function onWindowLoad() {

        if (window.cordova && window.PhoneGap && window.phonegap && window.device) {
            // on device add ready listener
            document.addEventListener('deviceready', onDeviceReady, false);
        } else {
            // on browser trigger onDeviceReady
            onDeviceReady();
        }

        window.removeEventListener('load', onWindowLoad, false);
    }

    window.addEventListener('load', onWindowLoad, false);

    function onDeviceReady() {
        // bootstrap app
        angular.element(document).ready(
            function () {
                angular.bootstrap(document, ['TrumanApp']);
            }
        );

        document.removeEventListener('deviceready', onDeviceReady, false);
    }

})(window, document);
