/**
 * @author John Foley <jpf7324@truman.edu>
 *
 * Controller for Truman Today tab
 */

angular.module(
    "TrumanApp.trumanToday",
    [
        'ionic',
        'TrumanApp.constants'
    ]
).controller(
    'TrumanTodayCtrl',
    [
        '$scope',
        '$http',
        '$log',
        'CONFIG',
        function ($scope, $http, $log, CONFIG) {

            /**
             * Initialize network error to not show
             * @type {boolean}
             */
            $scope.networkError = false;

            /**
             * @author John Foley
             * @param _url
             *
             * Opens the specified url using the system browser
             * requires this plugin: cordova plugin add org.apache.cordova.inappbrowser
             */
            $scope.open = function (_url) {
                window.open(_url, '_blank', 'location=yes');
            };

            /**
             * Initialize loading screen to now show
             * @type {boolean}
             */
            $scope.toggleLoading = false;

            $http.get(
                CONFIG.TRUMAN_TODAY_FEED_API_URL,
                {
                    withCredentials: false,
                    cache: CONFIG.CACHE_ENABLED
                }
            ).success(
                function (data, status, headers, config) {

                    $scope.toggleLoading = true;
                    $scope.networkError = false;

                    $scope.trumanTodayFeed = data._embedded.truman_today_feed[0].item;

                }
            ).error(
                function (data, status, headers, config) {

                    // called asynchronously if an error occurs
                    // or server returns response with an error status.
                    $scope.networkError = true;
                    $scope.toggleLoading = true;
                }
            );
        }
    ]
);