/**
 * @author John Foley
 * @author Curtis Kelsey <kelseyc@truman.edu>
 *
 * Calendar Controller
 *
 * Manages the action of retrieving and storing information for the Truman Calendar Events
 */
angular.module(
    'TrumanApp.calendar',
    [
        'ionic',
        'TrumanApp.services.grouping'
    ]
).filter(
    'moment',
    function () {

        return function (dateString, format) {

            var DATETIME_FORMAT = 'YYYYMMDD[T]HHmmss[Z]';
            var DATETIME_FORMAT2 = 'YYYYMMDD[T]HHmmss';
            var DATE_FORMAT = 'YYYYMMDD';

            return moment.utc(
                dateString,
                [DATETIME_FORMAT2, DATETIME_FORMAT, DATE_FORMAT]
            ).local().format(format);
        };
    }
).controller(
    'CalendarCtrl',
    [
        '$scope',
        'eventGroupByDateService',
        '$http',
        '$log',
        'CONFIG',
        function ($scope, eventGroupByDateService, $http, $log, CONFIG) {

            /**
             * Initializes the loading to not hide
             * @type {boolean}
             */
            $scope.hideLoading = false;

            /**
             * Initialize to not show
             * @type {boolean}
             */
            $scope.failureNetwork = false;

            /**
             * Simple logic to group events by their date.
             *
             * @see eventGroupByDateService
             * @param newDate
             * @returns {boolean}
             */
            $scope.groupTitle = function (newDate) {

                if (eventGroupByDateService.isNew(newDate)) {

                    $scope.prettyCurrDate = eventGroupByDateService.beautify(newDate);

                    return true;
                }

                return false;
            };

            $http.get(
                CONFIG.CAMPUS_EVENTS_API_URL,
                {
                    withCredentials: false,
                    cache: CONFIG.CACHE_ENABLED
                }
            ).success(
                function (data, status, headers, config) {

                    $scope.hideLoading = true;

                    $scope.calendarEvents = data._embedded.events;
                    console.log($scope.calendarEvents);
                }
            ).error(
                function (data, status, headers, config) {

                    // called asynchronously if an error occurs
                    // or server returns response with an error status.
                    $scope.hideLoading = true;

                    $scope.failureNetwork = true;
                }
            );
        }
    ]
);
