/**
 * @author John Foley <jpf7324@truman.edu>
 * @author Curtis Kelsey <kelseyc@truman.edu>
 *
 * Very simple controller for the Department Feeds tab
 */

angular.module(
    "TrumanApp.departmentFeeds",
    [
        'ionic'
    ]
).filter(
    "departmentSubstringFilter",
    function () {
        
        return function (items, searchText) {

            // Has the item loaded yet
            if (!items) {
                return;
            }

            // Do we have anything to search for?
            if (!searchText) {
                return items;
            }

            // Initialize array and then loop through the list, finding if a substring exists in title
            var filtered = [];

            angular.forEach(
                items,
                function (item) {

                    if (item.title && item.title.toLowerCase().indexOf(searchText.toLowerCase()) > -1) {
                        
                        filtered.push(item);
                    }
                }
            );

            return filtered;
        }
    }
).controller(
    'DepartmentFeedsCtrl',
    [
        '$scope',
        '$http',
        '$ionicScrollDelegate',
        '$log',
        'CONFIG',
        function ($scope, $http, $ionicScrollDelegate, $log, CONFIG) {

            /**
             * Initialize loading to not hide
             * @type {boolean}
             */
            $scope.hideLoading = false;

            /**
             * Initialize network error message to hide
             * @type {boolean}
             */
            $scope.failureNetwork = false;

            /**
             * Initialize list to show
             * @type {boolean}
             */
            $scope.showList = true;

            /**
             * Initialize feeds to not show
             * @type {boolean}
             */
            $scope.showFeed = false;

            /**
             * @author John Foley
             * @param _url
             *
             * Opens the specified url using the system browser
             * requires this plugin: cordova plugin add org.apache.cordova.inappbrowser
             */
            $scope.open = function (_url) {
                window.open(_url, '_blank', 'location=yes');
            };

            /**
             * Starts with each screen at the top
             */
            $ionicScrollDelegate.scrollTop();

            $http.get(CONFIG.FEED_LIST_API_URL).success(
                function (response) {

                    $scope.hideLoading = true;
                    $scope.feeds = response;
                }
            ).error(
                function (response) {

                    $scope.hideLoading = true;
                    $scope.failureNetwork = true;
                    $scope.showList = false;
                }
            );

            $scope.getFeed = function (feed) {

                var _urlFeeds = CONFIG.DEPT_FEED_API_URL + "?department=",
                    _departmentFeed = _urlFeeds + feed.toLowerCase();

                $scope.hideLoading = false;

                $http.get(_departmentFeed).success(
                    function (res) {

                        $scope.hideLoading = true;
                        $scope.showList = false;
                        $scope.showFeed = true;
                        $scope.departmentFeed = res._embedded.feeds;

                        $ionicScrollDelegate.scrollTop();
                    }
                ).error(
                    function () {

                        $scope.hideLoading = true;
                        $scope.failureNetwork = true;
                        $scope.showList = false;
                    }
                );
            };

            $scope.goBack = function () {

                $scope.showList = true;
                $scope.showFeed = false;
            }
        }
    ]
);