/**
 * @author John Foley <jpf7324@truman.edu>
 * @author Curtis Kelsey <kelseyc@truman.edu>
 *
 * Controller for grades
 * The term format is YYYYSS - where SS is the semester code
 * 10 = spring
 * 20 = may interim
 * 40 = summer
 * 50 = august interim
 * 60 = fall
 * 70 = winter interim
 *
 * so the current semester is 201460
 */
angular.module(
    'TrumanApp.grades', [
        'ionic',
        'TrumanApp.services'
    ]
)

.directive(
    "scrollTop",
    function ($timeout, $ionicScrollDelegate) {
        return {
            restrict: 'A',
            link: function (scope, element) {
                element.bind(
                    'click',
                    function () {
                        $timeout(
                            function () {
                                $ionicScrollDelegate.scrollTop();
                            }
                        );
                    }
                )
            }
        }
    }
)

.controller(
    'GradesCtrl',
    [
        '$scope', '$http', '$log', 'CONFIG',
        function ($scope, $http, $log, CONFIG) {

            /**
             * Checkbox truthy value
             * @type {boolean}
             */
            //$scope.rememberMe = false;

            /**
             *
             * @type {Array}
             */
            $scope.terms = [];

            if (!$scope.terms.length > 0) {

                // Grab the terms from the REST API
                $http.get(CONFIG.TERMS_API_URL).success(
                    function (res, status, headers) {

                        $scope.terms = res._embedded.terms;
                    }
                )
                // Network error?
                .error(
                    function (data, status, headers, config) {

                        $scope.failureNetwork = true;
                        $scope.showLogin = false;
                    }
                );
            }

            /**
             * Initialize the loading screen to hide
             * @type {boolean}
             */
            $scope.toggleLoading = true;

            /**
             * Initialize the failure messages to not show
             * @type {boolean}
             */
            $scope.failureLogin = false;
            $scope.failureNetwork = false;

            /**
             * Initialize showLogin to show
             * @type {boolean}
             */
            $scope.showLogin = true;

            /**
             * The user information that is input at run time
             * @type {{}}
             */
            $scope.user = {};

            /**
             * Empty object for our post data
             * @type {{}}
             */
            var data = {};

            /**
             * @author John Foley
             * @param _url
             *
             * Opens the specified url using the system browser
             * requires this plugin: cordova plugin add org.apache.cordova.inappbrowser
             */
            $scope.open = function (_url) {
                window.open(_url, '_blank', 'location=yes');
            };

            /**
             * Function called when the user is finished with input or a login config exists
             */
            $scope.login = function () {

                // Set the loading screen to not hide
                $scope.toggleLoading = false;

                // User is finished with the login form, so not show
                $scope.showLogin = false;

                $scope.foundGrades = true;

                // File does not exist, so accept new user input
                // Copy the data and get ready to send it
                data = angular.copy($scope.user);
                $log.debug(data);

                // Execute the POST, giving it the URL, input data, and header configuration
                $http.post(
                    CONFIG.BANNER_GRADES_API_URL,
                    data,
                    {
                        withCredentials: false,
                        cache: CONFIG.CACHE_ENABLED
                    }
                ).success(
                    function (res, status, headers, config) {

                        // Hide the loading screen
                        $scope.toggleLoading = true;

                        // Is the response a successful status?
                        if (res._embedded[0].status.status == "success") {

                            // Give the template the correct information
                            $scope.grades = res._embedded[0].response.response.grades;

                            if ($scope.grades.length == 0) {
                                // No grades were found
                                $scope.foundGrades = false;
                            }
                        } else {

                            // Show the failure message; query did not succeed on ITS' server side
                            $scope.failureLogin = true;
                        }
                    }
                )
                // Network error?
                .error(
                    function (data, status, headers, config) {

                        // show the failure message and hide the loading screen
                        $scope.toggleLoading = true;
                        $scope.failureNetwork = true;
                    }
                );
            };

            /**
             * Reset the UI and send us back to login
             */
            $scope.backToLogin = function () {

                $scope.failureLogin = false;
                $scope.showLogin = true;
                data = {};
                //$scope.user.password = "GARBAGE";
                $scope.rememberMe = false;
            };
        }
    ]
);