/**
 * @author John Foley <jpf7324@truman.edu>
 * @author Curtis Kelsey <kelseyc@truman.edu>
 *
 * Very simple controller for the liveStream tab
 */
angular.module(
    "TrumanApp.liveStream",
    [
        'ionic',
        'TrumanApp.services'
    ]
).directive(
    "darkenParentOnClick",
    function () {
        return function (scope, element) {

            var clickingCallback = function () {

                element.parent().addClass("background-active");

                setTimeout(
                    function () {
                        element.parent().removeClass("background-active");
                    },
                    250
                )
            };

            element.bind(
                'click',
                clickingCallback
            );
        }
    }
).controller(
    'LiveStreamCtrl',
    [
        '$scope',
        '$interval',
        'mediaService',
        '$http',
        '$rootScope',
        '$timeout',
        '$log',
        'CONFIG',
        function ($scope, $interval, mediaService, $http, $rootScope, $timeout, $log, CONFIG) {

            var media = mediaService.media;

            $scope.nowPlaying = "";
            $scope.showPlay = true;
            $scope.showPause = false;

            $scope.play = function () {

                $log.debug('Playing...');

                media.play();
                $scope.showGears = true;
                $scope.showPause = false;
                $scope.showPlay = false;

                $timeout(
                    function () {

                        $scope.showGears = false;
                        $scope.showPause = true;
                        $scope.showPlay = false;
                    },
                    6000
                );
            };

            $scope.stop = function () {

                $log.debug('Stopping...');

                media.stop();
                $scope.showPause = false;
                $scope.showPlay = true;
            };

            /**
             * Initialize network error to false
             * @type {boolean}
             */
            $scope.failureNetwork = false;

            $interval(
                function () {

                    $http.get(CONFIG.KTRM_NOW_PLAYING_URL).success(
                        function (response) {

                            $log.debug(response);
                            $scope.nowPlaying = response;
                        }
                    ).error(
                        function (response) {

                            $log.error(response);
                            $scope.failureNetwork = true;
                        }
                    )
                },
                10000
            )
        }
    ]
);