/**
 * @author John Foley <jpf7324@truman.edu>
 * @author Curtis Kelsey <kelseyc@truman.edu>
 */

angular.module(
    'TrumanApp.map',
    [
        'ionic'
    ]
).controller(
    'MapCtrl',
    [
        '$scope',
        '$cordovaGeolocation',
        '$log',
        function ($scope, $cordovaGeolocation, $log) {

            $log.debug('Say Map!');

            var _timeout = 30000,
                map;

            function watchMe() {

                var watchOptions = {
                    frequency: 1000,
                    timeout: _timeout,
                    enableHighAccuracy: false // may cause errors if true
                };

                var watch = $cordovaGeolocation.watchPosition(watchOptions),
                    marker;

                watch.then(
                    null,
                    function (error) {

                        $log.error(error);
                        alert("Geolocation error! " + error.message);
                    },
                    function (position) {

                        $log.debug(position);

                        clearMarkers();
                        var lat = position.coords.latitude,
                            long = position.coords.longitude,
                            latLong = new google.maps.LatLng(lat, long);

                        marker = new google.maps.Marker(
                            {
                                position: latLong,
                                map: map,
                                title: 'my location'
                            }
                        );
                    }
                );
            }

            document.addEventListener(
                "deviceready",
                onDeviceReady,
                false
            );

            function onDeviceReady() {

                $log.debug('Device is ready.');

                var mapOptions = {
                    zoom: 15,
                    center: new google.maps.LatLng(40.185589, -92.581892),
                    mapTypeId: google.maps.MapTypeId.ROADMAP
                };

                map = new google.maps.Map(
                    document.getElementById('map'),
                    mapOptions
                );

                var GeoMarker = new GeolocationMarker(map);
            }
        }
    ]
);