/**
 * @author John Foley <jpf7324@truman.edu>
 * @author Curtis Kelsey <kelseyc@truman.edu>
 *
 * Controller for the schedule feature. User logs in, and then the user can view their schedule
 * TODO: Previous and next buttons to allow for schedule traversal
 * TODO: Import into native calendar feature
 */
angular.module(
    'TrumanApp.schedule',
    [
        'ionic',
        'TrumanApp.services'
    ]
).directive(
    "scrollTop",
    function ($timeout, $ionicScrollDelegate) {
        return {
            restrict: 'A',
            link: function (scope, element) {
                element.bind(
                    'click',
                    function () {
                        $timeout(
                            function () {
                                $ionicScrollDelegate.scrollTop();
                            }
                        );
                    }
                )
            }
        }
    }
).controller(
    'ScheduleCtrl',
    [
        '$scope',
        '$http',
        '$cordovaDatePicker',
        '$log',
        'CONFIG',
        function ($scope, $http, $cordovaDatePicker, $log, CONFIG) {

            /**
             * Initialize the loading screen to hide
             * @type {boolean}
             */
            $scope.toggleLoading = true;

            /**
             * Initialize the failure messages to not show
             * @type {boolean}
             */
            $scope.failureLogin = false;
            $scope.failureNetwork = false;

            /**
             * Flag for whether or not any schedule items were found
             * @type {boolean}
             */
            $scope.foundSchedule = false;

            /**
             * Initialize showLogin to show
             * @type {boolean}
             */
            $scope.showLogin = true;

            /**
             * Container for the terms
             * @type {Array}
             */
            $scope.terms = [];

            /**
             * The user information that is input at run time
             * @type {{}}
             */
            $scope.user = {};

            /**
             * Empty object for our post data
             * @type {{}}
             */
            var data = {};

            if (!$scope.terms.length > 0) {

                // Grab the terms from the REST API
                $http.get(CONFIG.TERMS_API_URL).success(
                    function (res, status, headers) {
                        //console.log(res);
                        $scope.terms = res._embedded.terms;
                    }
                ).error(
                    function (data, status, headers, config) {

                        $scope.failureNetwork = true;
                        $scope.showLogin = false;
                    }
                );
            }

            /**
             * @author John Foley
             * @param _url
             *
             * Opens the specified url using the system browser
             * requres this plugin: cordova plugin add org.apache.cordova.inappbrowser

             */
            $scope.open = function (_url) {
                window.open(_url, '_blank', 'location=yes');
            };

            /**
             * Function called when the user is finished with input or a login config exists
             */
            $scope.login = function () {

                // Set the loading screen to not hide
                $scope.toggleLoading = false;

                // User is finished with the login form, so not show
                $scope.showLogin = false;


                // File does not exist, so accept new user input
                // Copy the data and get ready to send it
                data = angular.copy($scope.user);

                $scope.terms.some(
                    function (term) {

                        //console.log(term);

                        if (term.ID == data.term) {
                            data.startDate = term.startdate.split(" ")[0];
                            data.endDate = term.enddate.split(" ")[0];
                            delete data.term;
                            return true;
                        }
                    }
                );

                // Execute the POST, giving it the URL, input data, and header configuration
                $http.post(
                    CONFIG.BANNER_SCHEDULE_API_URL,
                    data,
                    {
                        withCredentials: false,
                        cache: CONFIG.CACHE_ENABLED
                    }
                ).success(
                    function (res, status, headers, config) {

                        // Hide the loading screen
                        $scope.toggleLoading = true;

                        //console.log(res);

                        // Is the response a successful status?
                        if (res._embedded[0].status.status == "success") {

                            // Give the template the correct information
                            $scope.schedule = res._embedded[0].response.response.dates;

                            $scope.schedule.forEach(
                                function (item) {

                                    if (item.courses.length > 1) {
                                        $scope.foundSchedule = true;
                                    }
                                }
                            );

                        } else {

                            // Show the failure message; query did not succeed on ITS' server side
                            $scope.failureLogin = true;
                        }
                    }
                ).error(
                    function (data, status, headers, config) {

                        // show the failure message and hide the loading screen
                        $scope.toggleLoading = true;
                        $scope.failureNetwork = true;
                    }
                );
            };

            /**
             * Reset the UI and send us back to login
             */
            $scope.backToLogin = function () {

                $scope.failureLogin = false;
                $scope.showLogin = true;
                data = {};
                //$scope.user.password = "GARBAGE";
                $scope.rememberMe = false;
            }
        }
    ]
);