/**
 * @author John Foley
 * @date 1/22/15
 *
 *  Controller for the search feature
 *
 *  Only searches the directory listing
 *
 *  @deps $scope, $http, $ionicSideMenuDelegate
 */
angular.module('TrumanApp.filters', []).
filter('htmlToPlaintext', function() {
        return function(text) {
            return  text ? String(text).replace(/<[^>]+>/gm, '') : '';
        };
    }
);

angular.module(
    'TrumanApp.search', [
        'ionic'
    ]
    )

    .directive(
        "scrollBottom",
        function ($timeout, $ionicScrollDelegate) {

            return {
                restrict: 'A',
                link: function (scope, element) {

                    element.bind(
                        'click',
                        function () {

                            $timeout(
                                function () {
                                    $ionicScrollDelegate.scrollBottom();
                                }
                            );
                        }
                    )
                }
            }
        }
    )

    .controller(
        'SearchCtrl',
        [
            '$scope',
            '$http',
            '$log',
            'CONFIG',
            function ($scope, $http, $log, CONFIG) {

                /**
                 * Initialize the search UI to show
                 * @type {boolean}
                 */
                $scope.showSearch = true;

                /**
                 *
                 * @type {boolean}
                 */
                $scope.networkError = false;

                /**
                 * Initialize the results UI to hide
                 * @type {boolean}
                 */
                $scope.showResults = false;

                /**
                 * Handy dandy search string, courtesy of Greg Marshall
                 * @type {string}
                 * @private
                 */
                var _url = "http://search.truman.edu/directories/api/v3.asp?mode=search&showall=1&q=",
                    _thunderstoneSearchUrl = "http://thunderstone.truman.edu/texis/search/main.xml",
                    alphabet = "ABCDEFGHIJKLMNOPQRSTUVWXYZ",
                    colorDictionary = {},
                    _publicProfileValue = 'Public',
                    _internalProfileValue = 'internal-meta';

                /**
                 * Generate the dictionary of {char: color} pairs.
                 */
                for (var c = 0; c < alphabet.length; c++) {

                    var nextChar = alphabet.charAt(c);
                    colorDictionary[nextChar] = Please.make_color();
                }

                /**
                 * Function to get the color at a character's place in the dictionary
                 * @param c
                 * @returns {*}
                 */
                $scope.getColor = function (c) {

                    return colorDictionary[c.toUpperCase()];
                };

                $scope.searchThunderstone = function (query) {

                    var _searchUrl = _thunderstoneSearchUrl;
                    _searchUrl += "?query=" + query + "&pr=" + _publicProfileValue;

                    console.log(_searchUrl);

                    /**
                     * We need to specify this for the header on the POST to be correct.
                     * @type {{withCredentials: boolean}}
                     */
                    $http.get(
                        _searchUrl,
                        {
                            withCredentials: false,
                            cache: CONFIG.CACHE_ENABLED
                        }
                        )
                        .success(
                            function (data) {

                                $log.debug(data);

                                data = jQuery.parseXML(data);

                                // Change out the UI
                                $scope.showSearch = false;
                                $scope.showSearchResults = true;

                                var results = data.getElementsByTagName("Result");
                                $log.debug(results);
                                $scope.searchResults = [];

                                for (var i = 0; i < results.length; i++) {

                                    $scope.searchResults.push(
                                        {
                                            colorIndex: (results[i].getElementsByTagName("ResultTitle")[0].innerHTML.match(/[a-zA-Z]/) || []).pop(),
                                            title: results[i].getElementsByTagName("ResultTitle")[0].innerHTML,
                                            url: results[i].getElementsByTagName("Url")[0].innerHTML,
                                            clickUrl: results[i].getElementsByTagName("ClickUrl")[0].innerHTML,
                                            urlDisplay: results[i].getElementsByTagName("UrlDisplay")[0].innerHTML,
                                            abstract: results[i].getElementsByTagName("Abstract")[0].innerHTML
                                        }
                                    );
                                }

                                console.log($scope.searchResults);
                            }
                        )
                        .error(
                            function (data) {

                                // failure
                                $log.error(data);
                                $scope.showSearch = false;
                                $scope.networkError = true;
                            }
                        );
                };

                /**
                 * Queries the search query and sets up the results
                 * @param query
                 */
                $scope.searchDirectory = function (query) {

                    $log.debug('Searching the directory...');

                    // Put the search string together
                    var _search_url = _url + query;

                    /**
                     * We need to specify this for the header on the POST to be correct.
                     * @type {{withCredentials: boolean}}
                     */
                    $http.get(
                        _search_url,
                        {
                            withCredentials: false,
                            cache: CONFIG.CACHE_ENABLED
                        }
                        )
                        .success(
                            function (data) {

                                // Change out the UI
                                $scope.showSearch = false;
                                $scope.showResults = true;

                                $scope.results = data;
                            }
                        )
                        .error(
                            function (data) {

                                // failure
                                $log.error(data);
                                $scope.showSearch = false;
                                $scope.networkError = true;
                            }
                        );
                };

                $scope.back = function() {

                    $scope.showSearch = true;
                    $scope.showResults = false;
                    $scope.showSearchResults = false;
                };

                $scope.openTel = function (tel) {

                    window.open("tel:" + tel, '_system');
                };

                $scope.openEmail = function (email) {

                    window.open("mailto:" + email, '_system');
                };

                /**
                 * @author John Foley
                 * @param _url
                 *
                 * Opens the specified url using the system browser
                 * requres this plugin: cordova plugin add org.apache.cordova.inappbrowser

                 */
                $scope.open = function (_url) {
                    window.open(_url, '_system', 'location=yes');
                }
            }
        ]
    );