/*jslint latedef:false*/
/**
 * @author John Foley <jpf7324@truman.edu>
 * @date 1/29/15
 */

'use strict';

describe('AppCtrl =>', function() {
    // Load the module with MainController
    beforeEach(module('TrumanApp'));

    var $controller, $scope, $ionicSideMenuDelegate;
    // inject the $controller and $rootScope services
    // in the beforeEach block
    // NOTE: The test runner will unwrap these variables for us during parsing.
    beforeEach(inject(function(_$controller_, $rootScope) {
        $scope = $rootScope.$new();
        // Create the controller
        $controller = _$controller_;
        function IonicSideMenuDelegateMock() {
            var rightOpen = false;
            var leftOpen = false;
            this.toggleRight = function() {
                rightOpen = !rightOpen;
            };
            this.toggleLeft = function() {
                leftOpen = !leftOpen;
            };
            this.isOpenLeft = function() {
                return leftOpen;
            };
            this.isOpenRight = function() {
                return rightOpen;
            };
        }
        $ionicSideMenuDelegate = new IonicSideMenuDelegateMock();
    }));

    describe('Behavior of menu icons =>', function() {
        //noinspection JSUnusedLocalSymbols
        var controller;

        beforeEach(function() {
            //noinspection JSUnusedLocalSymbols
            controller = $controller('AppCtrl',
                {
                    $scope: $scope,
                    $ionicSideMenuDelegate: $ionicSideMenuDelegate
                }
            );
        });

        describe('Behavior of right menu =>', function() {
            it('Should close when open', function() {
                // Ensure right menu is open
                $ionicSideMenuDelegate.toggleRight();
                expect($ionicSideMenuDelegate.isOpenRight()).toBe(true);

                // Test the correct function
                $scope.openRight();

                // Expect right function to close
                expect($ionicSideMenuDelegate.isOpenRight()).toBe(false);

                // Verify the appropriate flags are changed
                expect($scope.leftNavVisible).toEqual(false);
                expect($scope.rightNavVisible).toEqual(false);
                expect($scope.mainContentVisible).toEqual(true)
            });

            it('Should open when closed', function() {
                // Ensure right menu is closed
                expect($ionicSideMenuDelegate.isOpenRight()).toBe(false);

                // Test the correct function
                $scope.openRight();

                // Expect right function to close
                expect($ionicSideMenuDelegate.isOpenRight()).toBe(true);

                // Verify the appropriate flags are changed
                expect($scope.leftNavVisible).toEqual(false);
                expect($scope.rightNavVisible).toEqual(true);
                expect($scope.mainContentVisible).toEqual(false)
            });
        });

        describe('Behavior of left menu =>', function() {
            it('Should close when open', function() {
                // Ensure left menu is open
                $ionicSideMenuDelegate.toggleLeft();
                expect($ionicSideMenuDelegate.isOpenLeft()).toBe(true);

                // Test the correct function
                $scope.openLeft();

                // Expect left function to close
                expect($ionicSideMenuDelegate.isOpenLeft()).toBe(false);

                // Verify the appropriate flags are changed
                expect($scope.leftNavVisible).toEqual(false);
                expect($scope.rightNavVisible).toEqual(false);
                expect($scope.mainContentVisible).toEqual(true)
            });

            it('Should open when closed', function() {
                // Ensure left menu is closed
                expect($ionicSideMenuDelegate.isOpenLeft()).toBe(false);

                // Test the correct function
                $scope.openLeft();

                // Expect left function to close
                expect($ionicSideMenuDelegate.isOpenLeft()).toBe(true);

                // Verify the appropriate flags are changed
                expect($scope.leftNavVisible).toEqual(true);
                expect($scope.rightNavVisible).toEqual(false);
                expect($scope.mainContentVisible).toEqual(false)
            });
        })
    });

    describe('close navigation function =>', function() {
        it('should close the side menus', function() {
            //noinspection JSUnusedLocalSymbols
            var controller = $controller('AppCtrl',
                {
                    $scope: $scope,
                    $ionicSideMenuDelegate: $ionicSideMenuDelegate
                }
            );

            $scope.leftNavVisible = false;
            $scope.rightNavVisible = false;
            $scope.mainContentVisible = true;

            $scope.closeNavigation();

            expect($scope.leftNavVisible).toEqual(false);
            expect($scope.rightNavVisible).toEqual(false);
            expect($scope.mainContentVisible).toEqual(true);
        })
    });
});
